@@ -8,6 +8,13 @@
 
 """
 
+        from pysol_cards.cwrap import create_gen
+        variant = "freecell"
+        DEALS_MS = 0
+        gen = create_gen(variant, DEALS_MS)
+        deal_idx = 240002
+        deal_s = gen(deal_idx)
+
 """
 
 from pysol_cards.cards import CardRenderer
@@ -15,7 +22,7 @@ from pysol_cards.deal_game import Game
 from pysol_cards.random import RandomBase
 
 
-rend = CardRenderer(True)
+_r = CardRenderer(True)
 
 
 def create_gen(game_variant, ms):
@@ -25,6 +32,5 @@ def create_gen(game_variant, ms):
     game = Game(game_variant, 1, which_deals, 13)
 
     def _ret(deal_idx):
-        s = game.calc_deal_string(deal_idx, rend)
-        return s
+        return game.calc_deal_string(deal_idx, _r)
     return _ret
